@@ -110,7 +110,7 @@ def register_core_options():
                          help_msg=help_msg)
 
     help_msg = 'Data directory for Avocado'
-    default = prepend_base_path('/var/lib/avocado/data')
+    default = prepend_base_path('~/avocado/data')
     stgs.register_option(section='datadir.paths',
                          key='data_dir',
                          key_type=prepend_base_path,
@@ -197,7 +197,7 @@ def initialize_plugin_infrastructure():
                          default=[],
                          help_msg=help_msg)
 
-    kinds = pkg_resources.get_entry_map('avocado-framework').keys()
+    kinds = list(pkg_resources.get_entry_map('avocado-framework').keys())
     plugin_types = [kind[8:] for kind in kinds
                     if kind.startswith('avocado.plugins.')]
     for plugin_type in plugin_types:
