@@ -70,7 +70,8 @@ class RunningMessageHandler(BaseMessageHandler):
         self._handlers = {'log': [LogMessageHandler()],
                           'stdout': [StdoutMessageHandler()],
                           'stderr': [StderrMessageHandler()],
-                          'whiteboard': [WhiteboardMessageHandler()]}
+                          'whiteboard': [WhiteboardMessageHandler()],
+                          'file': [FileMessageHandler()]}
 
     def process_message(self, message, task, job):
         for handler in self._handlers.get(message.get('type'), []):
@@ -84,12 +85,11 @@ class StartMessageHandler(BaseMessageHandler):
     It will create the test base directories and triggers the 'start_test'
     event.
 
-    This is triggered when the runner starts the test.
+    This have to be triggered when the runner starts the test.
 
-    The started message properties:
-    param status: 'started'
-    param time: start time of the test
-    type time: float
+    :param status: 'started'
+    :param time: start time of the test
+    :type time: float
 
     example: {'status': 'started', 'time': 16444.819830573}
     """
@@ -120,12 +120,14 @@ class FinishMessageHandler(BaseMessageHandler):
 
     This is triggered when the runner ends the test.
 
-    The finished message properties:
-    param status: 'finished'
-    param result: test result
-    type result: `avocado.core.teststatus.STATUSES`
-    param time: end time of the test
-    type time: float
+    :param status: 'finished'
+    :param result: test result
+    :type result: `avocado.core.teststatus.STATUSES`
+    :param time: end time of the test
+    :type time: float
+    :param fail_reason: Optional parameter for brief specification, of the
+                       failed result.
+    :type fail_reason: string
 
     example: {'status': 'finished', 'result': 'pass', 'time': 16444.819830573}
     """
@@ -153,10 +155,54 @@ class BaseRunningMessageHandler(BaseMessageHandler):
     """Base interface for resolving running messages."""
 
     @staticmethod
-    def _save_message_to_file(filename, buff, task, mode='a'):
+    def _message_to_line(message, encoding):
+        """
+        Converts the message to string.
+
+        When the message doesn't end with a new line, the new line is added.
+
+        :param message: message for decoding
+        :type message: bytes
+        :param encoding: encoding of the message
+        :type encoding: str
+        :return: encoded message with new line character
+        :rtype: str
+        """
+        message = message.decode(encoding)
+        if not message.endswith("\n"):
+            message = "%s\n" % message
+        return message
+
+    @staticmethod
+    def _save_message_to_file(filename, buff, task, encoding=None):
+        """
+        Method for saving messages into the file
+
+        It can decode and save messages.The message will be decoded when
+        encoding is not None. When the decoded message doesn't end with a new
+        line the new line will be added. Every message is saved in the append
+        mode.
+
+        :param filename: name of the file
+        :type filename: str
+        :param buff: message to be saved
+        :type buff: bytes
+        :param task: message related task.
+        :type task: :class:`avocado.core.nrunner.Task`
+        :param encoding: encoding of buff, default is None
+        :type encoding: str
+        """
+
+        def _save_to_file(file_name, mode):
+            with open(file_name, mode) as fp:
+                fp.write(buff)
+
         file = os.path.join(task.metadata['task_path'], filename)
-        with open(file, mode) as fp:
-            fp.write(buff)
+        if encoding:
+            buff = BaseRunningMessageHandler._message_to_line(buff, encoding)
+            _save_to_file(file, "a")
+        else:
+            _save_to_file(file, "ab")
 
 
 class LogMessageHandler(BaseRunningMessageHandler):
@@ -165,13 +211,12 @@ class LogMessageHandler(BaseRunningMessageHandler):
 
     It will save the log to the debug.log file in the task directory.
 
-    The log message properties:
-    param status: 'running'
-    param type: 'log'
-    param log: log message
-    type log: string
-    param time: Time stamp of the message
-    type time: float
+    :param status: 'running'
+    :param type: 'log'
+    :param log: log message
+    :type log: string
+    :param time: Time stamp of the message
+    :type time: float
 
     example: {'status': 'running', 'type': 'log', 'log': 'log message',
              'time': 18405.55351474}
@@ -182,12 +227,9 @@ class LogMessageHandler(BaseRunningMessageHandler):
 
         This assumes that the log message will not contain a newline, and thus
         one is explicitly added here.
-
-        TODO: consider moving the responsibility of formatting to the producer
-              of all log messages to allow for transparent handling of both
-              text and binary logs.
         """
-        self._save_message_to_file('debug.log', "%s\n" % message['log'], task)
+        self._save_message_to_file('debug.log', message['log'], task,
+                                   message.get('encoding', None))
 
 
 class StdoutMessageHandler(BaseRunningMessageHandler):
@@ -196,20 +238,22 @@ class StdoutMessageHandler(BaseRunningMessageHandler):
 
     It will save the stdout to the stdout file in the task directory.
 
-    The log message properties:
-    param status: 'running'
-    param type: 'stdout'
-    param log: stdout message
-    type log: string
-    param time: Time stamp of the message
-    type time: float
+    :param status: 'running'
+    :param type: 'stdout'
+    :param log: stdout message
+    :type log: bytes
+    :param encoding: optional value for decoding messages
+    :type encoding: str
+    :param time: Time stamp of the message
+    :type time: float
 
     example: {'status': 'running', 'type': 'stdout', 'log': 'stdout message',
              'time': 18405.55351474}
     """
 
     def handle(self, message, task, job):
-        self._save_message_to_file('stdout', message['log'], task, mode='ab')
+        self._save_message_to_file('stdout', message['log'], task,
+                                   message.get('encoding', None))
 
 
 class StderrMessageHandler(BaseRunningMessageHandler):
@@ -218,20 +262,22 @@ class StderrMessageHandler(BaseRunningMessageHandler):
 
     It will save the stderr to the stderr file in the task directory.
 
-    The log message properties:
-    param status: 'running'
-    param type: 'stderr'
-    param log: stderr message
-    type log: string
-    param time: Time stamp of the message
-    type time: float
+    :param status: 'running'
+    :param type: 'stderr'
+    :param log: stderr message
+    :type log: bytes
+    :param encoding: optional value for decoding messages
+    :type encoding: str
+    :param time: Time stamp of the message
+    :type time: float
 
     example: {'status': 'running', 'type': 'stderr', 'log': 'stderr message',
              'time': 18405.55351474}
     """
 
     def handle(self, message, task, job):
-        self._save_message_to_file('stderr', message['log'], task, mode='ab')
+        self._save_message_to_file('stderr', message['log'], task,
+                                   message.get('encoding', None))
 
 
 class WhiteboardMessageHandler(BaseRunningMessageHandler):
@@ -240,17 +286,52 @@ class WhiteboardMessageHandler(BaseRunningMessageHandler):
 
     It will save the stderr to the whiteboard file in the task directory.
 
-    The log message properties:
-    param status: 'running'
-    param type: 'whiteboard'
-    param log: whiteboard message
-    type log: string
-    param time: Time stamp of the message
-    type time: float
+    :param status: 'running'
+    :param type: 'whiteboard'
+    :param log: whiteboard message
+    :type log: bytes
+    :param encoding: optional value for decoding messages
+    :type encoding: str
+    :param time: Time stamp of the message
+    :type time: float
 
     example: {'status': 'running', 'type': 'whiteboard',
              'log': 'whiteboard message', 'time': 18405.55351474}
     """
 
     def handle(self, message, task, job):
-        self._save_message_to_file('whiteboard', message['log'], task)
+        self._save_message_to_file('whiteboard', message['log'], task,
+                                   message.get('encoding', None))
+
+
+class FileMessageHandler(BaseRunningMessageHandler):
+    """
+    Handler for file message.
+
+    In task directory will save log into the runner specific file. When the
+    file doesn't exist, the file will be created. If the file exist,
+    the message data will be appended at the end.
+
+    :param status: 'running'
+    :param type: 'file'
+    :param path: relative path to the file. The file will be created under
+                the Task directory and the absolute path will be created
+                as `absolute_task_directory_path/relative_file_path`.
+    :type path: string
+    :param log: data to be saved inside file
+    :type log: bytes
+    :param time: Time stamp of the message
+    :type time: float
+
+    example: {'status': 'running', 'type': 'file', 'path':'foo/runner.log',
+             'log': 'this will be saved inside file',
+             'time': 18405.55351474}
+    """
+
+    def handle(self, message, task, job):
+        filename = os.path.relpath(os.path.join("/", message['path']), "/")
+        file = os.path.join(task.metadata['task_path'], filename)
+        if not os.path.exists(file):
+            os.makedirs(os.path.dirname(file))
+        self._save_message_to_file(filename, message['log'], task,
+                                   message.get('encoding', None))
