@@ -67,7 +67,6 @@ def resolutions_to_runnables(resolutions, config):
     filter_by_tags = config.get("filter.by_tags.tags")
     include_empty = config.get("filter.by_tags.include_empty")
     include_empty_key = config.get('filter.by_tags.include_empty_key')
-    runner_config = settings.filter_config(config, r'^runner\.')
     for resolution in resolutions:
         if resolution.result != ReferenceResolutionResult.SUCCESS:
             continue
@@ -78,7 +77,7 @@ def resolutions_to_runnables(resolutions, config):
                                                  include_empty,
                                                  include_empty_key):
                     continue
-            runnable.config = runner_config
+            runnable.config = config
             result.append(runnable)
     return result
 
@@ -103,8 +102,7 @@ class TestSuite:
         self._runner = None
         self._test_parameters = None
 
-        if (self.config.get('run.dry_run.enabled') and
-                self.config.get('run.test_runner') == 'runner'):
+        if self.config.get('run.dry_run.enabled'):
             self._convert_to_dry_run()
 
         if self.size == 0:
@@ -119,8 +117,12 @@ class TestSuite:
         return self.size
 
     def _convert_to_dry_run(self):
-        for i in range(self.size):
-            self.tests[i] = [DryRunTest, self.tests[i][1]]
+        if self.config.get('run.test_runner') == 'nrunner':
+            for runnable in self.tests:
+                runnable.kind = 'dry-run'
+        else:
+            for i in range(self.size):
+                self.tests[i] = [DryRunTest, self.tests[i][1]]
 
     @classmethod
     def _from_config_with_loader(cls, config, name=None):
