@@ -21,13 +21,11 @@ import shutil
 import subprocess
 import time
 
+from ..utils import astring, genio
+from ..utils import path as utils_path
+from ..utils import process, software_manager
 from . import output
 from .settings import settings
-from ..utils import astring
-from ..utils import genio
-from ..utils import process
-from ..utils import software_manager
-from ..utils import path as utils_path
 
 log = logging.getLogger("avocado.sysinfo")
 
@@ -97,6 +95,16 @@ class Logfile(Collectible):
         :param logdir: Log directory which the file is going to be copied to.
         """
         if os.path.exists(self.path):
+            config = settings.as_dict()
+            if config.get('sysinfo.collect.optimize') and logdir.endswith('post'):
+                pre_file = os.path.join(os.path.dirname(logdir), 'pre',
+                                        self.logf)
+                if os.path.isfile(pre_file):
+                    with open(self.path) as f1, open(pre_file) as f2:
+                        if f1.read() == f2.read():
+                            log.debug("Not logging %s (no change detected)",
+                                      self.path)
+                            return
             try:
                 shutil.copyfile(self.path, os.path.join(logdir, self.logf))
             except IOError:
@@ -150,13 +158,13 @@ class Command(Collectible):
         :param logdir: Path to a log directory.
         """
         env = os.environ.copy()
+        config = settings.as_dict()
         if "PATH" not in env:
             env["PATH"] = "/usr/bin:/bin"
-        locale = settings.get_value("sysinfo.collect", "locale", str, None)
+        locale = config.get("sysinfo.collect.locale")
         if locale:
             env["LC_ALL"] = locale
-        timeout = settings.get_value("sysinfo.collect", "commands_timeout",
-                                     int, -1)
+        timeout = config.get('sysinfo.collect.commands_timeout')
         # the sysinfo configuration supports negative or zero integer values
         # but the avocado.utils.process APIs define no timeouts as "None"
         if int(timeout) <= 0:
@@ -167,6 +175,7 @@ class Command(Collectible):
                                  verbose=False,
                                  ignore_status=True,
                                  allow_output_check='combined',
+                                 shell=True,
                                  env=env)
         except FileNotFoundError as exc_fnf:
             log.debug("Not logging '%s' (command '%s' was not found)", self.cmd,
@@ -176,6 +185,14 @@ class Command(Collectible):
             log.warning('Could not execute "%s": %s', self.cmd, exc)
             return
         logf_path = os.path.join(logdir, self.logf)
+        if config.get('sysinfo.collect.optimize') and logdir.endswith('post'):
+            pre_file = os.path.join(os.path.dirname(logdir), 'pre', self.logf)
+            if os.path.isfile(pre_file):
+                with open(pre_file, 'rb') as f1:
+                    if f1.read() == result.stdout:
+                        log.debug("Not logging %s (no change detected)",
+                                  self.cmd)
+                        return
         if self._compress_log:
             with gzip.GzipFile(logf_path, 'wb') as logf:
                 logf.write(result.stdout)
@@ -205,9 +222,10 @@ class Daemon(Command):
         :param logdir: Path to a log directory.
         """
         env = os.environ.copy()
+        config = settings.as_dict()
         if "PATH" not in env:
             env["PATH"] = "/usr/bin:/bin"
-        locale = settings.get_value("sysinfo.collect", "locale", str, None)
+        locale = config.get("sysinfo.collect.locale")
         if locale:
             env["LC_ALL"] = locale
         logf_path = os.path.join(logdir, self.logf)
@@ -253,7 +271,8 @@ class JournalctlWatcher(Collectible):
         super(JournalctlWatcher, self).__init__(logf)
         self.cursor = self._get_cursor()
 
-    def _get_cursor(self):
+    @staticmethod
+    def _get_cursor():
         try:
             cmd = 'journalctl --quiet --lines 1 --output json'
             result = process.system_output(cmd, verbose=False)
@@ -386,72 +405,24 @@ class SysInfo:
         :param profiler: Whether to use the profiler. If not given explicitly,
                          tries to look in the config files.
         """
+        self.config = settings.as_dict()
+
         if basedir is None:
             basedir = utils_path.init_dir('sysinfo')
         self.basedir = basedir
 
         self._installed_pkgs = None
         if log_packages is None:
-            self.log_packages = settings.get_value('sysinfo.collect',
-                                                   'installed_packages',
-                                                   key_type='bool',
-                                                   default=False)
+            packages_namespace = 'sysinfo.collect.installed_packages'
+            self.log_packages = self.config.get(packages_namespace)
         else:
             self.log_packages = log_packages
 
-        commands_file = settings.get_value('sysinfo.collectibles',
-                                           'commands',
-                                           key_type='path',
-                                           default='')
-
-        if os.path.isfile(commands_file):
-            log.info('Commands configured by file: %s', commands_file)
-            self.commands = genio.read_all_lines(commands_file)
-        else:
-            log.debug('File %s does not exist.', commands_file)
-            self.commands = []
-
-        files_file = settings.get_value('sysinfo.collectibles',
-                                        'files',
-                                        key_type='path',
-                                        default='')
-        if os.path.isfile(files_file):
-            log.info('Files configured by file: %s', files_file)
-            self.files = genio.read_all_lines(files_file)
-        else:
-            log.debug('File %s does not exist.', files_file)
-            self.files = []
-
-        if profiler is None:
-            self.profiler = settings.get_value('sysinfo.collect',
-                                               'profiler',
-                                               key_type='bool',
-                                               default=False)
-        else:
-            self.profiler = profiler
-
-        profiler_file = settings.get_value('sysinfo.collectibles',
-                                           'profilers',
-                                           key_type='path',
-                                           default='')
-        if os.path.isfile(profiler_file):
-            self.profilers = genio.read_all_lines(profiler_file)
-            log.info('Profilers configured by file: %s', profiler_file)
-            if not self.profilers:
-                self.profiler = False
-
-            if self.profiler is False:
-                if not self.profilers:
-                    log.info('Profiler disabled: no profiler'
-                             ' commands configured')
-                else:
-                    log.info('Profiler disabled')
-        else:
-            log.debug('File %s does not exist.', profiler_file)
-            self.profilers = []
+        self._get_collectibles(profiler)
 
         self.start_collectibles = set()
         self.end_collectibles = set()
+        self.end_fail_collectibles = set()
 
         self.pre_dir = utils_path.init_dir(self.basedir, 'pre')
         self.post_dir = utils_path.init_dir(self.basedir, 'post')
@@ -459,7 +430,53 @@ class SysInfo:
 
         self._set_collectibles()
 
-    def _get_syslog_watcher(self):
+    def _get_collectibles(self, c_profiler):
+        self.sysinfo_files = {}
+
+        for collectible in ['commands', 'files', 'fail_commands', 'fail_files']:
+            tmp_file = self.config.get(
+                'sysinfo.collectibles.%s' % collectible)
+            if os.path.isfile(tmp_file):
+                log.info('%s configured by file: %s', collectible.title(),
+                         tmp_file)
+                self.sysinfo_files[collectible] = genio.read_all_lines(
+                    tmp_file)
+            else:
+                log.debug('File %s does not exist.', tmp_file)
+                self.sysinfo_files[collectible] = []
+
+            if 'fail_' in collectible:
+                list1 = self.sysinfo_files[collectible]
+                list2 = self.sysinfo_files[collectible.split('_')[1]]
+                self.sysinfo_files[collectible] = [
+                    tmp for tmp in list1 if tmp not in list2]
+
+        profiler = c_profiler
+        if profiler is None:
+            self.profiler = self.config.get('sysinfo.collect.profiler')
+        else:
+            self.profiler = profiler
+
+        profiler_file = self.config.get('sysinfo.collectibles.profilers')
+        if os.path.isfile(profiler_file):
+            self.sysinfo_files["profilers"] = genio.read_all_lines(
+                profiler_file)
+            log.info('Profilers configured by file: %s', profiler_file)
+            if not self.sysinfo_files["profilers"]:
+                self.profiler = False
+
+            if self.profiler is False:
+                if not self.sysinfo_files["profilers"]:
+                    log.info('Profiler disabled: no profiler'
+                             ' commands configured')
+                else:
+                    log.info('Profiler disabled')
+        else:
+            log.debug('File %s does not exist.', profiler_file)
+            self.sysinfo_files["profilers"] = []
+
+    @staticmethod
+    def _get_syslog_watcher():
         logpaths = ["/var/log/messages",
                     "/var/log/syslog",
                     "/var/log/system.log"]
@@ -471,17 +488,23 @@ class SysInfo:
 
     def _set_collectibles(self):
         if self.profiler:
-            for cmd in self.profilers:
+            for cmd in self.sysinfo_files["profilers"]:
                 self.start_collectibles.add(Daemon(cmd))
 
-        for cmd in self.commands:
+        for cmd in self.sysinfo_files["commands"]:
             self.start_collectibles.add(Command(cmd))
             self.end_collectibles.add(Command(cmd))
 
-        for filename in self.files:
+        for fail_cmd in self.sysinfo_files["fail_commands"]:
+            self.end_fail_collectibles.add(Command(fail_cmd))
+
+        for filename in self.sysinfo_files["files"]:
             self.start_collectibles.add(Logfile(filename))
             self.end_collectibles.add(Logfile(filename))
 
+        for fail_filename in self.sysinfo_files["fail_files"]:
+            self.end_fail_collectibles.add(Logfile(fail_filename))
+
         self.end_collectibles.add(JournalctlWatcher())
 
     def _get_installed_packages(self):
@@ -510,6 +533,7 @@ class SysInfo:
 
     def start(self):
         """Log all collectibles at the start of the event."""
+        os.environ['AVOCADO_SYSINFODIR'] = self.pre_dir
         for log_hook in self.start_collectibles:
             if isinstance(log_hook, Daemon):  # log daemons in profile directory
                 log_hook.run(self.profile_dir)
@@ -519,12 +543,18 @@ class SysInfo:
         if self.log_packages:
             self._log_installed_packages(self.pre_dir)
 
-    def end(self):
+    def end(self, status=""):
         """
         Logging hook called whenever a job finishes.
         """
+        os.environ['AVOCADO_SYSINFODIR'] = self.post_dir
         for log_hook in self.end_collectibles:
             log_hook.run(self.post_dir)
+
+        if status == "FAIL":
+            for log_hook in self.end_fail_collectibles:
+                log_hook.run(self.post_dir)
+
         # Stop daemon(s) started previously
         for log_hook in self.start_collectibles:
             if isinstance(log_hook, Daemon):
