@@ -100,8 +100,8 @@ class Config(CLICmd):
             LOG_UI.debug("file to customize values")
             LOG_UI.debug('')
             LOG_UI.info('Avocado Data Directories:')
-            LOG_UI.debug('    base     %s', data_dir.get_base_dir())
-            LOG_UI.debug('    tests    %s', data_dir.get_test_dir())
-            LOG_UI.debug('    data     %s', data_dir.get_data_dir())
-            LOG_UI.debug('    logs     %s', data_dir.get_logs_dir())
-            LOG_UI.debug('    cache    %s', ", ".join(cache_dirs))
+            LOG_UI.debug('   base    %s', data_dir.get_base_dir())
+            LOG_UI.debug('   tests   %s', data_dir.get_test_dir())
+            LOG_UI.debug('   data    %s', config.get('datadir.paths.data_dir'))
+            LOG_UI.debug('   logs    %s', config.get('datadir.paths.logs_dir'))
+            LOG_UI.debug('   cache   %s', ", ".join(cache_dirs))
