@@ -167,6 +167,9 @@ class Runner(RunnerInterface):
             task_id = TestID(prefix,
                              name,
                              None)
+            # with --dry-run we don't want to run requirement
+            if runnable.kind == 'dry-run':
+                requirement_runnable.kind = 'noop'
             # creates the requirement task
             requirement_task = nrunner.Task(requirement_runnable,
                                             task_id,
@@ -180,40 +183,72 @@ class Runner(RunnerInterface):
 
         return requirements_runtime_tasks
 
+    @staticmethod
+    def _create_runtime_tasks_for_test(test_suite, runnable, no_digits,
+                                       index, status_uris, variant):
+        """Creates runtime tasks for both tests, and for its requirements."""
+        result = []
+        # test related operations
+        if test_suite.name:
+            prefix = "{}-{}".format(test_suite.name, index)
+        else:
+            prefix = index
+        test_id = TestID(prefix,
+                         runnable.uri,
+                         variant,
+                         no_digits)
+        # handles the test task
+        task = nrunner.Task(runnable, test_id, status_uris,
+                            nrunner.RUNNERS_REGISTRY_PYTHON_CLASS)
+        runtime_task = RuntimeTask(task)
+        result.append(runtime_task)
+
+        # handles the requirements
+        requirements_runtime_tasks = (
+            Runner._get_requirements_runtime_tasks(runnable,
+                                                   prefix,
+                                                   status_uris))
+        # extend the list of tasks with the requirements runtime tasks
+        if requirements_runtime_tasks is not None:
+            for requirement_runtime_task in requirements_runtime_tasks:
+                # make sure we track the dependencies of a task
+                runtime_task.task.dependencies.add(
+                    requirement_runtime_task.task)
+            result.extend(requirements_runtime_tasks)
+
+        return result
+
     @staticmethod
     def _get_all_runtime_tasks(test_suite):
         runtime_tasks = []
-        no_digits = len(str(len(test_suite)))
+        test_result_total = test_suite.variants.get_number_of_tests(test_suite.tests)
+        no_digits = len(str(test_result_total))
         status_uris = [test_suite.config.get('nrunner.status_server_uri')]
-        for index, runnable in enumerate(test_suite.tests, start=1):
-            # test related operations
-            if test_suite.name:
-                prefix = "{}-{}".format(test_suite.name, index)
-            else:
-                prefix = index
-            test_id = TestID(prefix,
-                             runnable.uri,
-                             None,
-                             no_digits)
-            # handles the test task
-            task = nrunner.Task(runnable, test_id, status_uris,
-                                nrunner.RUNNERS_REGISTRY_PYTHON_CLASS)
-            runtime_task = RuntimeTask(task)
-            runtime_tasks.append(runtime_task)
-
-            # handles the requirements
-            requirements_runtime_tasks = (
-                Runner._get_requirements_runtime_tasks(runnable,
-                                                       prefix,
-                                                       status_uris))
-            # extend the list of tasks with the requirements runtime tasks
-            if requirements_runtime_tasks is not None:
-                for requirement_runtime_task in requirements_runtime_tasks:
-                    # make sure we track the dependencies of a task
-                    runtime_task.task.dependencies.add(
-                        requirement_runtime_task.task)
-                runtime_tasks.extend(requirements_runtime_tasks)
-
+        execution_order = test_suite.config.get('run.execution_order')
+        if execution_order == "variants-per-test":
+            for index, (runnable, variant) in enumerate(((test, variant)
+                                                         for test in test_suite.tests
+                                                         for variant in test_suite.variants.itertests()),
+                                                        start=1):
+                runtime_tasks.extend(Runner._create_runtime_tasks_for_test(
+                    test_suite,
+                    runnable,
+                    no_digits,
+                    index,
+                    status_uris,
+                    variant))
+        elif execution_order == "tests-per-variant":
+            for index, (runnable, variant) in enumerate(((test, variant)
+                                                         for variant in test_suite.variants.itertests()
+                                                         for test in test_suite.tests),
+                                                        start=1):
+                runtime_tasks.extend(Runner._create_runtime_tasks_for_test(
+                    test_suite,
+                    runnable,
+                    no_digits,
+                    index,
+                    status_uris,
+                    variant))
         return runtime_tasks
 
     def _start_status_server(self, status_server_listen):
@@ -226,7 +261,7 @@ class Runner(RunnerInterface):
 
     async def _update_status(self, job):
         tasks_by_id = {str(runtime_task.task.identifier): runtime_task.task
-                       for runtime_task in self.tasks}
+                       for runtime_task in self.runtime_tasks}
         message_handler = MessageHandler()
         while True:
             try:
@@ -242,25 +277,26 @@ class Runner(RunnerInterface):
             message_handler.process_message(message, task, job)
 
     def run_suite(self, job, test_suite):
-        # pylint: disable=W0201
-        self.summary = set()
+        summary = set()
 
         test_suite.tests, _ = nrunner.check_runnables_runner_requirements(
             test_suite.tests)
-        job.result.tests_total = test_suite.size  # no support for variants yet
+        job.result.tests_total = test_suite.variants.get_number_of_tests(test_suite.tests)
 
         listen = test_suite.config.get('nrunner.status_server_listen')
         self._start_status_server(listen)
 
         # pylint: disable=W0201
-        self.tasks = self._get_all_runtime_tasks(test_suite)
+        self.runtime_tasks = self._get_all_runtime_tasks(test_suite)
         if test_suite.config.get('nrunner.shuffle'):
-            random.shuffle(self.tasks)
-        tsm = TaskStateMachine(self.tasks, self.status_repo)
+            random.shuffle(self.runtime_tasks)
+        test_ids = [rt.task.identifier for rt in self.runtime_tasks
+                    if rt.task.category == 'test']
+        tsm = TaskStateMachine(self.runtime_tasks, self.status_repo)
         spawner_name = test_suite.config.get('nrunner.spawner')
         spawner = SpawnerDispatcher(test_suite.config)[spawner_name].obj
         max_running = min(test_suite.config.get('nrunner.max_parallel_tasks'),
-                          len(self.tasks))
+                          len(self.runtime_tasks))
         timeout = test_suite.config.get('task.timeout.running')
         workers = [Worker(state_machine=tsm,
                           spawner=spawner,
@@ -273,7 +309,7 @@ class Runner(RunnerInterface):
             loop.run_until_complete(asyncio.wait_for(asyncio.gather(*workers),
                                                      job.timeout or None))
         except (KeyboardInterrupt, asyncio.TimeoutError):
-            self.summary.add("INTERRUPTED")
+            summary.add("INTERRUPTED")
 
         # Wait until all messages may have been processed by the
         # status_updater. This should be replaced by a mechanism
@@ -285,4 +321,9 @@ class Runner(RunnerInterface):
 
         job.result.end_tests()
         self.status_server.close()
-        return self.summary
+
+        # Update the overall summary with found test statuses, which will
+        # determine the Avocado command line exit status
+        summary.update([status.upper() for status in
+                        self.status_repo.get_result_set_for_tasks(test_ids)])
+        return summary
