@@ -17,6 +17,8 @@
 This module provides an useful API for hosts in a network.
 """
 
+import json
+
 from ..ssh import Session
 from .common import run_command
 from .exceptions import NWException
@@ -43,6 +45,7 @@ class Host:
         for i in remote.interfaces:
             print(i.name, i.is_link_up())
     """
+
     def __init__(self, host):
         if type(self) == Host:
             raise TypeError("Host class should not be instantiated")
@@ -64,6 +67,19 @@ class Host:
             if ipaddr in interface.get_ipaddrs():
                 return interface
 
+    def get_default_route_interface(self):
+        """Get a list of default routes interfaces
+
+        :return: list of interface names
+        """
+        cmd = "ip -j route list default"
+        output = run_command(cmd, self)
+        try:
+            result = json.loads(output)
+            return [str(item['dev']) for item in result]
+        except Exception as ex:
+            raise NWException("could not get default route interface name: {}".format(ex))
+
 
 class LocalHost(Host):
     """
@@ -76,6 +92,7 @@ class LocalHost(Host):
 
         local = LocalHost()
     """
+
     def __init__(self, host='localhost'):
         super().__init__(host)
 
@@ -95,6 +112,7 @@ class RemoteHost(Host):
 
     You can also provide a key instead of a password.
     """
+
     def __init__(self, host, username, port=22, key=None, password=None):
         super().__init__(host)
         self.port = port
