@@ -3,7 +3,6 @@
 import base64
 
 from avocado import Test
-from avocado import main
 
 
 class WhiteBoard(Test):
@@ -17,7 +16,3 @@ class WhiteBoard(Test):
         This should write a message to the whiteboard.
         """
         self.whiteboard = base64.encodebytes(b'My message encoded in base64').decode('ascii')
-
-
-if __name__ == "__main__":
-    main()
