@@ -178,9 +178,9 @@ class RunnerOperationTest(TestCaseTmpDir):
         self.assertEqual(result.exit_status, expected_rc,
                          "Avocado did not return rc %d:\n%s" %
                          (expected_rc, result))
-        self.assertIn('    base     ' + mapping['base_dir'], result.stdout_text)
-        self.assertIn('    data     ' + mapping['data_dir'], result.stdout_text)
-        self.assertIn('    logs     ' + mapping['logs_dir'], result.stdout_text)
+        self.assertIn('   base    ' + mapping['base_dir'], result.stdout_text)
+        self.assertIn('   data    ' + mapping['data_dir'], result.stdout_text)
+        self.assertIn('   logs    ' + mapping['logs_dir'], result.stdout_text)
 
     def test_runner_phases(self):
         cmd_line = ('%s run --disable-sysinfo --job-results-dir %s '
@@ -518,8 +518,15 @@ class RunnerOperationTest(TestCaseTmpDir):
             avocado_process.wait()
 
     def test_dry_run(self):
-        cmd = ("%s run --disable-sysinfo --dry-run --dry-run-no-cleanup --json - "
-               "-- passtest.py failtest.py gendata.py " % AVOCADO)
+        examples_path = os.path.join('examples', 'tests')
+        passtest = os.path.join(examples_path, 'passtest.py')
+        failtest = os.path.join(examples_path, 'failtest.py')
+        gendata = os.path.join(examples_path, 'gendata.py')
+        cmd = ("%s run --test-runner=nrunner --disable-sysinfo --dry-run "
+               "--dry-run-no-cleanup --json - -- %s %s %s " % (AVOCADO,
+                                                               passtest,
+                                                               failtest,
+                                                               gendata))
         number_of_tests = 3
         result = json.loads(process.run(cmd).stdout_text)
         debuglog = result['debuglog']
@@ -722,9 +729,9 @@ class RunnerSimpleTest(TestCaseTmpDir):
         one_hundred = 'failtest.py ' * 100
         cmd_line = ('%s run --job-results-dir %s --disable-sysinfo %s'
                     % (AVOCADO, self.tmpdir.name, one_hundred))
-        initial_time = time.time()
+        initial_time = time.monotonic()
         result = process.run(cmd_line, ignore_status=True)
-        actual_time = time.time() - initial_time
+        actual_time = time.monotonic() - initial_time
         self.assertLess(actual_time, 30.0)
         expected_rc = exit_codes.AVOCADO_TESTS_FAIL
         self.assertEqual(result.exit_status, expected_rc,
@@ -742,9 +749,9 @@ class RunnerSimpleTest(TestCaseTmpDir):
                             'sleeptest.py')
         cmd_line = ('%s run --job-results-dir %s --disable-sysinfo %s'
                     % (AVOCADO, self.tmpdir.name, sleep_fail_sleep))
-        initial_time = time.time()
+        initial_time = time.monotonic()
         result = process.run(cmd_line, ignore_status=True)
-        actual_time = time.time() - initial_time
+        actual_time = time.monotonic() - initial_time
         self.assertLess(actual_time, 33.0)
         expected_rc = exit_codes.AVOCADO_TESTS_FAIL
         self.assertEqual(result.exit_status, expected_rc,
@@ -847,8 +854,8 @@ class RunnerSimpleTest(TestCaseTmpDir):
         os.kill(pid, signal.SIGTSTP)   # This freezes the process
         # The deadline is 3s timeout + 10s test postprocess before kill +
         # 10s reserve for additional steps (still below 60s)
-        deadline = time.time() + 20
-        while time.time() < deadline:
+        deadline = time.monotonic() + 20
+        while time.monotonic() < deadline:
             if not proc.is_alive():
                 break
             time.sleep(0.1)
