@@ -2,8 +2,8 @@ import stat
 import unittest
 
 from avocado.utils import process, script
+from selftests.utils import AVOCADO
 
-from .. import AVOCADO
 # Use the same definitions from loader to make sure the behavior
 # is also the same
 from .test_loader import AVOCADO_TEST_OK as AVOCADO_INSTRUMENTED_TEST
