@@ -3,8 +3,7 @@ import unittest
 
 from avocado.core import exit_codes
 from avocado.utils import process, script
-
-from .. import AVOCADO, TestCaseTmpDir, skipOnLevelsInferiorThan
+from selftests.utils import AVOCADO, TestCaseTmpDir, skipOnLevelsInferiorThan
 
 COMMANDS_TIMEOUT_CONF = """
 [sysinfo.collect]
