@@ -2,22 +2,14 @@ import os
 import unittest
 
 from avocado.utils import distro, software_manager
-
-from ... import setup_avocado_loggers
+from selftests.utils import setup_avocado_loggers
 
 setup_avocado_loggers()
 
 
 def apt_supported_distro():
-    """
-    The only Linux distributions this was tested on
-    """
-    this = distro.detect()
-    if this.name == 'debian':
-        return this.version == '9' and this.release == '6'
-    elif this.name == 'Ubuntu':
-        return this.version == '18' and this.release == '04'
-    return False
+    """Distros we expect to have the apt backend selected."""
+    return distro.detect().name in ['debian', 'Ubuntu']
 
 
 @unittest.skipUnless(os.getuid() == 0, "This test requires root privileges")
@@ -27,7 +19,8 @@ class Apt(unittest.TestCase):
     def test_provides(self):
         sm = software_manager.SoftwareManager()
         self.assertEqual(sm.provides('/bin/login'), 'login')
-        self.assertTrue(isinstance(sm.backend, software_manager.AptBackend))
+        self.assertTrue(isinstance(sm.backend,
+                                   software_manager.backends.apt.AptBackend))
 
 
 if __name__ == '__main__':
